@@ -4,8 +4,10 @@ import openpyxl
 import shutil
 import PySimpleGUI as sg
 import sys
+import os
 from Excelutilities.importing_data_helpers import is_col_block_bool
 from Excelutilities import index_helpers
+import pkg_resources
 first_and_last_row_index = index_helpers.first_and_last_row_index
 is_from_single_col = index_helpers.is_from_single_col
 
@@ -24,8 +26,7 @@ def export_data():
                             "Qty":7, "ORDER DATE":8, "CONDITION":9, "PRICE":10}
     to_read_after_product_id = ["SKU","PURCHASE PRICE", "Qty", "ORDER DATE", "CONDITION", "PRICE"]
 
-
-    default_file_loc = r"C:\Users\ethan\Documents\master_sheet.xlsm"
+    default_file_loc = xw.apps.active.books.active.fullname
     layout = [[sg.Text('Select the file location of the master sheet'), sg.Input(default_file_loc),sg.FileBrowse(key="--input_file--")],
                 [sg.OK(), sg.Cancel()]]
     event, values = sg.Window("",layout, no_titlebar=True, keep_on_top=True, grab_anywhere=True).read(close=True)
@@ -123,11 +124,15 @@ def export_data():
     internal_names_to_output_names = {"id_type":"product-id-type", "SKU":"sku", "CONDITION":"item-condition", "PRICE":"price"}
     output_names_to_internal_names = reversed_dict(internal_names_to_output_names)
 
-    src_path = r"C:\Users\ethan\Downloads\james example.xlsm"
-    dest_path = r"C:\Users\ethan\Downloads\james example2.xlsm"
-    shutil.copyfile(src_path, dest_path)
+    AMAZON_MASTER_FILE = pkg_resources.resource_filename('ArbMasterPy', 'data/Amazon standard inventory - flat file.xlsm')
+    src_path = AMAZON_MASTER_FILE
+    layout = [[sg.Text('Select the output location of your master sheet'), sg.Input(),sg.FolderBrowse(key="--input_file--")],
+                [sg.OK(), sg.Cancel()]]
+    event, values = sg.Window("",layout, no_titlebar=True, keep_on_top=True, grab_anywhere=True).read(close=True)
 
-    print()
+    dest_path=os.path.join(values[0], "amazon_master_output.xlsm")
+
+    shutil.copyfile(src_path, dest_path)
 
     return_array = []
     for product_id in product_id_to_data:
@@ -197,3 +202,5 @@ def generate_sku(allowed_data_types = [str]):
 
 # if __name__=="__main__":
 #     export_data()
+
+export_data()
\ No newline at end of file
